@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000019';
+$LWP::ConsoleLogger::VERSION = '0.000020';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -355,7 +355,8 @@ sub _parse_body {
     }
     elsif ( lc $subtype eq 'json' ) {
         try {
-            $content = p( decode_json($content), return_value => 'dump' );
+            $content = decode_json($content);
+            $content = p( $content, return_value => 'dump' );
         }
         catch { $t->row("Error parsing JSON: $_") };
     }
@@ -405,7 +406,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000019
+version 0.000020
 
 =head1 SYNOPSIS
 
